from load_and_preprocess_data import load_and_preprocess_data
from genrator import genrate_response
from rouge import Rouge
from sklearn.feature_extraction.text import TfidfVectorizer
from sklearn.metrics.pairwise import cosine_similarity

# Initialize ROUGE evaluator
rouge = Rouge()

# Load the data
df = load_and_preprocess_data()

def create_prompt(examples, query):
    prompt = "You are provided with examples of content followed by their corresponding reasons summarized in a few words, comma-separated. Please summarize the new content similarly.\n\n"
    i = 0
    for index, row in examples.iterrows():
        prompt += f"{i}. Content: {row['Content']}\n"
        prompt += f"{i}. Summary of Claim: {row['Reasons']}\n\n"
        i += 1
    
    prompt += "Now, summarize the following content:\n"
    prompt += f"Content: {query}\n"
    prompt += "Just Output the Summary of the Claim as a string and nothing else\n"
    
    return prompt

def perfomance_on_data():

    # Initialize accumulators for ROUGE and Cosine scores
    total_rouge_1 = 0
    total_rouge_2 = 0
    total_rouge_l = 0
    total_cosine = 0
    num_examples = 0

    # Iterate over the dataset
    for query, reason in zip(df['Content'], df['Reasons']):
        examples = df.sample(7)
        prompt = create_prompt(examples, query)
        try:
            response = genrate_response(prompt)
            generated_summary = response.text

            # Calculate ROUGE score
            rouge_scores = rouge.get_scores(generated_summary, reason, avg=True)
            total_rouge_1 += rouge_scores['rouge-1']['f']
            total_rouge_2 += rouge_scores['rouge-2']['f']
            total_rouge_l += rouge_scores['rouge-l']['f']

            # Calculate Cosine Similarity
            vectorizer = TfidfVectorizer().fit_transform([generated_summary, reason])
            vectors = vectorizer.toarray()
            cosine_sim = cosine_similarity([vectors[0]], [vectors[1]])[0][0]
            total_cosine += cosine_sim

            num_examples += 1
            print(response.text)
            print(generated_summary)
            print(reason)
            print(rouge_scores)
            print(cosine_sim)

        except Exception as error:
            print("Something went wrong:", error)
        print("=====================================")

    # Compute average scores
    if num_examples > 0:
        avg_rouge_1 = total_rouge_1 / num_examples
        avg_rouge_2 = total_rouge_2 / num_examples
        avg_rouge_l = total_rouge_l / num_examples
        avg_cosine = total_cosine / num_examples

        print(f"Average ROUGE-1 F1 Score: {avg_rouge_1}")
        print(f"Average ROUGE-2 F1 Score: {avg_rouge_2}")
        print(f"Average ROUGE-L F1 Score: {avg_rouge_l}")
        print(f"Average Cosine Similarity: {avg_cosine}")
    else:
        print("No valid examples were processed.")


def genrate_on_query():
    print("Enter the Content")
    query = input()
    examples = df.sample(7)
    prompt = create_prompt(examples, query)
    try:
        print("Summary of Claims ")
        response = genrate_response(prompt)
        print(response.text)
    except Exception as error:
        print("Something went wrong:", error)



import pandas as pd
from sklearn.preprocessing import LabelEncoder

def load_and_preprocess_data():

    # Load the data
    df = pd.read_csv('./enterpret.csv')

    #  Remove rows where 'Content' is '<AUDIO_CONTENT>' or empty string
    df = df[(df['Content'] != '<AUDIO_CONTENT>') & (df['Content'].str.strip() != '')]

    # Remove rows where 'Reasons' and 'Content' is NaN
    df = df[df['Reasons'].notna()]  # Remove rows where 'reason' is NaN
    df = df[df['Content'].notna()]  # Remove rows where 'reason' is NaN

    df = df[(df['Reasons'].str.strip() != '') & (df['Reasons'].str.strip() != float('NaN')) ]

    # Handle missing values in 'source', 'sentiment', and 'type'
    # Fill missing values with the mode
    for column in ['Source', 'Type', 'Record Sentiment']:
        mode_value = df[column].mode()[0]
        df[column] = df[column].fillna(mode_value)

    # Convert 'source', 'sentiment', and 'type' into categorical classes
    label_encoders = {}
    for column in ['Source', 'Type', 'Record Sentiment']:
        le = LabelEncoder()
        df[column] = le.fit_transform(df[column])
        label_encoders[column] = le  # Store the label encoder if you need to inverse transform later


    data = pd.DataFrame()
    for column in ['Source', 'Type', 'Record Sentiment','Content','Reasons']:
        data[column]=df[column]
    df=data


    # Remove rows where 'Reasons' is empty
    df = df[df['Reasons'].map(len)>0]

    # Pre-process the strings of df['Reasons']
    temp = pd.DataFrame()
    i=0
    temp['Reasons']=df['Reasons']
    for it in df['Reasons']:
        if(len(it[0])>2):
            temp['Reasons'][i]=it[0]
            i+=1
    #     print(it[0])
    temp.head()
    df['Reasons']=temp['Reasons']
    return df








from setuptools import setup, find_packages

setup(
    name='IdentificationOfClaims',           
    version='0.1.1',
    packages=find_packages(),
    author='Manav',
    description='Identifies Claims from Text',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    install_requires=['google-generativeai','pandas','scikit-learn','numpy','nltk','rouge','scipy','python-dotenv'],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)



import google.generativeai as genai
import os
from dotenv import load_dotenv
load_dotenv()

genai.configure(api_key=os.environ["API_KEY"])
model = genai.GenerativeModel("gemini-1.5-flash")

def genrate_response(prompt1):

    response = model.generate_content(prompt1)
    return response
    # try:    
    #     # print(response.text)
    # except Exception as error:
    #     print("Someting Got Wrong")
    #     print(error)
    #     return {"text":0,"error_message":"Someting Got Wrong"}
